==> haskell-loch-th-0.2.2-20-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 loch-th
version:              0.2.2
visibility:           public
id:                   loch-th-0.2.2-9BgWjfvfQlC6hIim63co7s
key:                  loch-th-0.2.2-9BgWjfvfQlC6hIim63co7s
license:              BSD-3-Clause
maintainer:           tomi@nomi.cz
author:               Tomas Janousek
homepage:             https://github.com/liskin/loch-th
synopsis:
    Support for precise error locations in source files (Template Haskell version)

description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.

category:             Development
abi:                  a7f8e30dcffa1d221b9205a51f6137ee
exposed:              True
exposed-modules:      Debug.Trace.LocationTH
import-dirs:          /usr/lib/ghc-9.2.8/site-local/loch-th-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loch-th
hs-libraries:         HSloch-th-0.2.2-9BgWjfvfQlC6hIim63co7s
depends:
    base-4.16.4.0 pretty-1.1.3.6 template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html:         /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loch-th-0.2.2-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 loch-th
version:              0.2.2
visibility:           public
id:                   loch-th-0.2.2-KhO3RAhgl8e7Bf6S6WNYkq
key:                  loch-th-0.2.2-KhO3RAhgl8e7Bf6S6WNYkq
license:              BSD-3-Clause
maintainer:           tomi@nomi.cz
author:               Tomas Janousek
homepage:             https://github.com/liskin/loch-th
synopsis:
    Support for precise error locations in source files (Template Haskell version)

description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.

category:             Development
abi:                  bbb2d2b54857ceb320a8ffacbf015b54
exposed:              True
exposed-modules:      Debug.Trace.LocationTH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/loch-th-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/loch-th-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-loch-th
hs-libraries:         HSloch-th-0.2.2-KhO3RAhgl8e7Bf6S6WNYkq
depends:
    base-4.17.2.1 pretty-1.1.3.6 template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html:         /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
